@@ -524,8 +524,8 @@ impl ProcessMemory {
     }
 
     /// Get the process ID
-    pub fn pid(&self) {
-        self.pid;
+    pub fn pid(&self) -> u32 {
+        self.pid
     }
 
     #[cfg(target_os = "macos")]
